@@ -10,7 +10,7 @@ class ProfileFactory(factory.django.DjangoModelFactory):
 
     user = factory.SubFactory(UserFactory)
     available = factory.Faker('null_boolean')
-    bio = factory.Faker('text', max_nb_chars=145)
+    job = factory.Faker('text', max_nb_chars=145)
     city = factory.Faker('city')
     phone = factory.Faker('phone_number')
     website = factory.Faker('url')
